@@ -1,7 +1,7 @@
 modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1,
                        gamdisp = NULL, second.ord = TRUE, nobs = NULL, uncond.se = "revised", parm.type = NULL){
   results <- NULL
-  known <- rep(0, 6) #create an identifier of class type for lm, glm, lme, mer, unmarked,
+  known <- 0 #create an identifier of class type for lm, glm, lme, mer, unmarked,
   ##extract classes
   mod.class <- unlist(lapply(X = cand.set, FUN = class))
   ##check if all are identical
@@ -12,14 +12,14 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     results <- modavgpred.glm(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               type = type, c.hat = c.hat, gamdisp = gamdisp, second.ord = second.ord, 
                               nobs = nobs, uncond.se = uncond.se)
-    known[1] <- 1
+    known <- 1
   }
 
   ##determine if lme
   if(identical(check.class, "lme"))  {
     results <- modavgpred.lme(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
-    known[2] <- 1
+    known <- 1
   }
 
   ##determine if mer
@@ -27,7 +27,7 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     results <- modavgpred.mer(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               type = type, c.hat = c.hat, second.ord = second.ord, nobs = nobs,
                               uncond.se = uncond.se)
-    known[3] <- 1
+    known <- 1
   }
 
   ##determine if unmarked
@@ -37,21 +37,29 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     results <- modavgpred.unmarked(cand.set = cand.set, modnames = modnames, newdata = newdata,
                                    type = type, c.hat = c.hat, second.ord = second.ord,
                                    nobs = nobs, uncond.se = uncond.se, parm.type = parm.type)
-    known[4] <- 1
+    known <- 1
   }
 
   ##determine if gls
   if(identical(check.class, "gls"))  {
     results <- modavgpred.gls(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
-    known[5] <- 1
+    known <- 1
   }
 
   ##determine if rlm
   if(identical(check.class, c("rlm", "lm")))  {
     results <- modavgpred.rlm(cand.set = cand.set, modnames = modnames, newdata = newdata,
                               second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
-    known[6] <- 1
+    known <- 1
+  }
+
+  ##determine if merMod
+  if(identical(check.class, "lmerMod") || identical(check.class, "glmerMod"))  {
+    results <- modavgpred.merMod(cand.set = cand.set, modnames = modnames, newdata = newdata,
+                                 type = type, c.hat = c.hat, second.ord = second.ord, nobs = nobs,
+                                 uncond.se = uncond.se)
+    known <- 1
   }
 
     
@@ -724,6 +732,122 @@ modavgpred.rlm <-
 
 
 
+modavgpred.merMod <- function(cand.set, modnames, newdata, type = "response", c.hat = 1, second.ord = TRUE,
+                              nobs = NULL, uncond.se = "revised") {
+  ##newdata is data frame with exact structure of the original data frame (same variable names and type)
+  if(c.hat != 1) {warning("\nThis function only allows \'c.hat = 1\' for \'merMod\' class objects\n")}
+
+  ##extract classes
+  mod.class <- unlist(lapply(X = cand.set, FUN = class))
+  ##check if all are identical
+  check.class <- unique(mod.class)
+
+  ##check that link function is the same for all models if linear predictor is used
+  if(identical(type, "link")) {
+    link.list <- unlist(lapply(X = cand.set, FUN = function(i) fam.link.mer(i)$link))
+    check.link <- unique(link.list)
+    if(length(check.link) > 1) stop("\nIt is not appropriate to compute a model-averaged beta estimate\n",
+                                        "from models using different link functions\n")
+  }
+
+ 
+  if(identical(check.class, "lmerMod") || identical(check.class, "glmerMod")) {
+
+       
+  ##determine number of observations in data set
+  nobserv <- dim(newdata)[1]
+
+  ##determine number of columns in data set
+  ncolumns <- dim(newdata)[2]
+
+  ##if only 1 column, add an additional column to avoid problems in computation with predictSE.mer( )
+  if(ncolumns == 1) newdata$blank.fake.column.NAs <- NA
+  
+  ##store AICc table
+  AICctab<-aictab(cand.set=cand.set, modnames=modnames, second.ord=second.ord, nobs=nobs, sort=FALSE)
+
+  ##create object to hold Model-averaged estimates and unconditional SE's
+  Mod.avg.out <- matrix(NA, nrow = nobserv, ncol = 2)
+  colnames(Mod.avg.out) <- c("Mod.avg.est", "Uncond.SE")
+
+
+  ##begin loop - AICc
+  if(second.ord == TRUE && c.hat == 1){
+    for (obs in 1:nobserv) {
+
+      ##extract fitted value for observation obs
+      fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                       type = type, level = 0)$fit))
+
+      ##extract SE for fitted value for observation obs
+      SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                      type = type, level = 0)$se.fit))
+
+
+      ##create temporary data.frame to store fitted values and SE 
+      AICctmp <- AICctab
+      AICctmp$fit <- fit
+      AICctmp$SE <- SE
+
+      ##compute model averaged prediction and store in output matrix
+      Mod.avg.out[obs, 1] <- sum(AICctmp$AICcWt*AICctmp$fit)
+      ##compute unconditional SE and store in output matrix
+
+      ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+      if(identical(uncond.se, "old")) {
+        Mod.avg.out[obs, 2] <- sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2))
+      }
+
+      ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+      if(identical(uncond.se, "revised")) {
+        Mod.avg.out[obs, 2] <- sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit - Mod.avg.out[obs, 1])^2)))
+      }
+    }
+  }
+
+
+
+
+  ##create temporary data.frame to store fitted values and SE - AIC
+  if(second.ord == FALSE && c.hat == 1) {
+    for (obs in 1:nobserv) {
+      
+      ##extract fitted value for observation obs
+      fit <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                       type = type, level = 0)$fit))
+      ##extract SE for fitted value for observation obs
+      SE <- unlist(lapply(X = cand.set, FUN = function(i) predictSE.mer(i, se.fit = TRUE, newdata = newdata[obs, ],
+                                      type = type, level = 0)$se.fit))
+
+      AICtmp <- AICctab
+      AICtmp$fit <- fit
+      AICtmp$SE <- SE
+
+      ##compute model averaged prediction and store in output matrix
+      Mod.avg.out[obs, 1] <- sum(AICtmp$AICWt*AICtmp$fit)
+
+      ##compute unconditional SE and store in output matrix
+      ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+      if(identical(uncond.se, "old")) {
+        Mod.avg.out[obs, 2] <- sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2))
+      }
+
+      ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+      if(identical(uncond.se, "revised")) {
+        Mod.avg.out[obs, 2] <- sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit - Mod.avg.out[obs, 1])^2)))
+      }  
+    }
+  }
+
+
+  Mod.pred.list <- list("type" = type, "mod.avg.pred" = Mod.avg.out[,1], "uncond.se" = Mod.avg.out[,2])
+  class(Mod.pred.list) <- c("modavgpred", "list")
+  return(Mod.pred.list)
+  } else {
+      stop("\nThis function is only appropriate with the \'merMod\' class\n")
+    }
+}
+
 
 
 
